@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -274,23 +274,28 @@ if __name__ == '__main__':
     print res.id, res.name
     for row in res:
         print row.name, row.id, '@===@'
-    print "raw: ", res.raw
+    print "raw: ", res.raw()
     res2 = a.all(a.qs.where(sb.F.id==2).select('*'))
     print "+++++++++++++++++++++++++++++++++++++++++++++++"
-    print ".....", (res + res2).raw, "...."
+    print ".....", (res + res2).raw(), "...."
     print "+++++++++++++++++++++++++++++++++++++++++++++++"
     print '---------------------------------------'
-    res = a.first(a.qs.select('*'))
-    print res.id, res.name
-    for k, v in res:
+    res3 = a.first(a.qs.select('*'))
+    print res3.id, res3.name
+    for k, v in res3:
         print k, v, '*===*'
-    print "raw: ", res.raw
-    print "????", (res + res).raw, "????"
-    print "$$$$", result.Result.fromRowResult(res).raw, "$$$$"
+    print "raw: ", res3.raw()
+    print "????", (res + res).raw(), "????"
+    print "$$$$", result.Result.fromRowResult(res3).raw(), "$$$$"
     print '---------------------------------------'
     print "###", res | None, result.RowResult.new() | res, "###"
     print '---------------------------------------'
     print "isinstance: ", isinstance(res, result.ResultProxy), "issubclass: ", issubclass(res.__class__, result.ResultProxy)
+    print "new: ", res3.raw(), '---', res.raw(), '---', (res3 + res).raw(), '---', (res3 + {'a':'b'}).raw()
+    print "+++: ", (res3 + res3).raw()
+    print "************************************************************************"
+    print '--------', (((res + {'gg':'goal'}) + res3) + res).raw(), '---------------'
+    print type((res + {'gg':'goal'}) + res3)
     del a
     #print sb.QS(getattr(sb.T, 'user_98')).where((sb.F.status == 1) & (sb.F.a == 'go')).delete()
     #print u.tables(sb.T.good).select('*')
